﻿$mydir = (Split-Path -parent $MyInvocation.MyCommand.Definition)
$toolsDir = ($mydir | Split-Path | Join-Path -ChildPath "tools")

$srcRoot = "$toolsDir\$packageName"

Import-Module PsGet
Install-ChocolateyZipPackage -PackageName $packageName `
                    -url "https://github.com/PowerShellOrg/DSC/archive/e006ad8a0fdb45c40921943f63af32be581a8f5d.zip" `
                    -unzipLocation "$srcRoot" `
                    -specificFolder ""


function Install-PSModuleFolders {
    param([string]$TopLevelFolderPath)

    #Get all top level folders from the "Resources" sub-folder
    $moduleFolders = gci $TopLevelFolderPath  -Directory
    write-host -ForegroundColor cyan ($moduleFolders|out-string)
    foreach($hostModuleFolder in $moduleFolders) {
        try {
            Write-host -ForegroundColor Green ("hostModuleFOlder: {0}" -f ($hostModuleFolder|out-string))
            $module = gci $hostModuleFolder.FullName -Filter "*.psd1"
            if(-not $module) {
                $module = gci $hostModuleFolder.FullName -Filter "*.psm1"
            }
            Write-host -ForegroundColor Green ([io.path]::GetFileNameWithoutExtension($module))
            Write-host -ForegroundColor Green $module.FullName

            #Install modules without importing (some are DSC resource only module, and ought not be treated as regular PowerShell modules)
            Install-Module -modulename ([io.path]::GetFileNameWithoutExtension($module)) -modulepath $module.Parent.FullName -global -force -DoNotImport:$true
        } catch {
            Write-Warning $_
        }
    }
}



$resources = gci $srcRoot -Filter "Resources" -Directory -Recurse | Select-Object -First 1 -Wait
Install-PSModuleFolders -TopLevelFolderPath $resources.FullName

$toolFolders = gci $srcRoot -Filter "Tooling" -Directory -Recurse | Select-Object -First 1 -Wait
Install-PSModuleFolders -TopLevelFolderPath $toolFolders.FullName






